@@ -60,7 +60,6 @@
 #include <sys/socket.h>
 #include <sys/uio.h>
 #include <netinet/in.h>
-#include <sys/errno.h>
 #include <sys/param.h>
 #include <sys/poll.h>
 #include <arpa/inet.h>
@@ -732,9 +731,14 @@ command_listen(char *argv0, int sk)
 
 		if (echo) {
 			if( !(MSG_NOTIFICATION & inmessage.msg_flags)) {
-				sendto(recvsk, inmessage.msg_iov->iov_base,
-				       error, 0, (struct sockaddr *)&msgname,
-				       sizeof(msgname));
+				if (sendto(recvsk, inmessage.msg_iov->iov_base,
+					   error, 0,
+					   (struct sockaddr *)&msgname,
+					   sizeof(msgname)) == -1) {
+					fprintf(stderr, "%s: error: %s.\n",
+						argv0, strerror(errno));
+					exit(1);
+				}
 			}
 		}
 
@@ -951,6 +955,7 @@ command_send(char *argv0, int *skp)
 				outmsg.msg_controllen = 0;
 				outmsg.msg_name = &remote_addr;
 				outmsg.msg_namelen = ra_len;
+				outmsg.msg_flags = 0;
 
 				error = sendmsg(sk, &outmsg, 0);
 			} else {
@@ -1087,6 +1092,7 @@ command_poll(char *argv0)
 		outmsg.msg_controllen = 0;
 		outmsg.msg_name = &remote_addr;
 		outmsg.msg_namelen = ra_len;
+		outmsg.msg_flags = 0;
 	}
 
 
@@ -1413,6 +1419,8 @@ append_addr(const char *parm, struct sockaddr *addrs, int *ret_count)
 	int count = orig_count;
 
 
+	if (!parm)
+		return NULL;
 	/* Get the entries for this host.  */
 	hst4 = gethostbyname(parm);
 	hst6 = gethostbyname2(parm, AF_INET6);
@@ -1468,7 +1476,7 @@ append_addr(const char *parm, struct sockaddr *addrs, int *ret_count)
 	if (NULL != hst4) {
 		for (j = 0; j < i4; ++j) {
 			b4ap = (struct sockaddr_in *)aptr;
-			bzero(b4ap, sizeof(*b4ap));
+			memset(b4ap, 0x00, sizeof(*b4ap));
 			b4ap->sin_family = AF_INET;
 			b4ap->sin_port = htons(local_port);
 			bcopy(hst4->h_addr_list[j], &b4ap->sin_addr,
@@ -1481,7 +1489,7 @@ append_addr(const char *parm, struct sockaddr *addrs, int *ret_count)
 	if (NULL != hst6) {
 		for (j = 0; j < i6; ++j) {
 			b6ap = (struct sockaddr_in6 *)aptr;
-			bzero(b6ap, sizeof(*b6ap));
+			memset(b6ap, 0x00, sizeof(*b6ap));
 			b6ap->sin6_family = AF_INET6;
 			b6ap->sin6_port =  htons(local_port);
 			b6ap->sin6_scope_id = if_index;
@@ -2352,19 +2360,19 @@ test_verify_assoc_change(struct msghdr *msg)
 	switch(sn->sn_assoc_change.sac_state)
 	{
 	case SCTP_COMM_UP:
-		printf("Recieved SCTP_COMM_UP\n");
+		printf("Received SCTP_COMM_UP\n");
 		break;
 	case SCTP_COMM_LOST:
-		printf("Recieved SCTP_COMM_LOST\n");
+		printf("Received SCTP_COMM_LOST\n");
 		break;
 	case SCTP_RESTART:
-		printf("Recieved SCTP_RESTART\n");
+		printf("Received SCTP_RESTART\n");
 		break;
 	case SCTP_SHUTDOWN_COMP:
-		printf("Recieved SCTP_SHUTDOWN_COMP\n");
+		printf("Received SCTP_SHUTDOWN_COMP\n");
 		break;
 	case SCTP_CANT_STR_ASSOC:
-		printf("Recieved SCTP_CANT_STR_ASSOC\n");
+		printf("Received SCTP_CANT_STR_ASSOC\n");
 		break;
 	}
 
