@@ -52,7 +52,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/uio.h>
-#include <sys/errno.h>
+#include <errno.h>
 #include <netinet/in.h>
 #include <netinet/sctp.h>
 #include <sctputil.h>
