@@ -23,25 +23,50 @@
 #include <netinet/sctp.h> /* SCTP_SOCKOPT_BINDX_* */
 #include <errno.h>
 
+#ifdef HAVE_SCTP_PEELOFF_FLAGS
+int
+sctp_peeloff_flags(int fd, sctp_assoc_t associd, unsigned flags)
+{
+	socklen_t peeloff_size = sizeof(sctp_peeloff_flags_arg_t);
+	sctp_peeloff_flags_arg_t peeloff;
+	int err;
+
+	if (!flags)
+		return sctp_peeloff(fd, associd);
+
+	peeloff.p_arg.associd = associd;
+	peeloff.p_arg.sd = 0;
+	peeloff.flags = flags;
+
+	err = getsockopt(fd, SOL_SCTP, SCTP_SOCKOPT_PEELOFF_FLAGS, &peeloff,
+			 &peeloff_size);
+
+	if (err < 0)
+		return err;
+
+	return peeloff.p_arg.sd;
+}
+#endif
+
 /* Branch off an association into a seperate socket.  This is a new SCTP API
  * described in the section 8.2 of the Sockets API Extensions for SCTP. 
  * This is implemented using the getsockopt() interface.
- */  
+ */
 int
 sctp_peeloff(int fd, sctp_assoc_t associd)
 {
+	socklen_t peeloff_size = sizeof(sctp_peeloff_arg_t);
 	sctp_peeloff_arg_t peeloff;
-	socklen_t peeloff_size = sizeof(peeloff);
 	int err;
 
 	peeloff.associd = associd;
 	peeloff.sd = 0;
-	err = getsockopt(fd, SOL_SCTP, SCTP_SOCKOPT_PEELOFF, &peeloff, 
-			 &peeloff_size); 
-	if (err < 0) {
+
+	err = getsockopt(fd, SOL_SCTP, SCTP_SOCKOPT_PEELOFF, &peeloff,
+			 &peeloff_size);
+
+	if (err < 0)
 		return err;
-	}
 
 	return peeloff.sd;
-
-} /* sctp_peeloff() */
+}
